@@ -128,6 +128,7 @@ unwanted_dirs = (
 		".pytest_cache",
 		".tox",
 		".tox4",
+		".nox",
 		"__pypackages__",
 		)
 """
@@ -136,6 +137,7 @@ A list of directories which will likely be unwanted when searching directory tre
 .. versionadded:: 2.3.0
 .. versionchanged:: 2.9.0  Added ``.hg`` (`mercurial <https://www.mercurial-scm.org>`_)
 .. versionchanged:: 3.0.0  Added ``__pypackages__`` (:pep:`582`)
+.. versionchanged:: 3.2.0  Added ``.nox`` (https://nox.thea.codes/)
 """
 
 
@@ -285,7 +287,7 @@ def relpath(path: PathLike, relative_to: Optional[PathLike] = None) -> pathlib.P
 	:param relative_to: The directory to find the path relative to.
 		Defaults to the current directory.
 	:no-default relative_to:
-	"""  # noqa D400
+	"""  # noqa: D400
 
 	if not isinstance(path, pathlib.Path):
 		path = pathlib.Path(path)
@@ -395,7 +397,7 @@ class PathPlus(pathlib.Path):
 	def _from_parts(cls, args, init=True):
 		return super()._from_parts(args)  # type: ignore
 
-	def __new__(cls: Type[_PP], *args, **kwargs) -> _PP:  # noqa D102
+	def __new__(cls: Type[_PP], *args, **kwargs) -> _PP:  # noqa: D102
 		if cls is PathPlus:
 			cls = WindowsPathPlus if os.name == "nt" else PosixPathPlus  # type: ignore
 
@@ -576,11 +578,11 @@ class PathPlus(pathlib.Path):
 		:param errors:
 
 		:return: The content of the file.
-		"""  # noqa D400
+		"""  # noqa: D400
 
 		return self.read_text(encoding=encoding, errors=errors).split('\n')
 
-	def open(  # type: ignore  # noqa A003
+	def open(  # type: ignore  # noqa: A003  # pylint: disable=redefined-builtin
 		self,
 		mode: str = 'r',
 		buffering: int = -1,
@@ -607,7 +609,7 @@ class PathPlus(pathlib.Path):
 		.. versionchanged:: 0.5.1
 
 			Defaults to Unix line endings (``LF``) on all platforms.
-		"""  # noqa D400
+		"""  # noqa: D400
 
 		if 'b' in mode:
 			encoding = None
@@ -887,6 +889,8 @@ class PathPlus(pathlib.Path):
 		.. versionadded:: 2.9.0
 
 		:param uri:
+
+		:rtype: :class:`~.PathPlus`
 		"""
 
 		parseresult = urllib.parse.urlparse(uri)
@@ -915,6 +919,41 @@ class PathPlus(pathlib.Path):
 
 		return cls(path)
 
+	def move(self: _PP, dst: PathLike) -> _PP:
+		"""
+		Recursively move ``self`` to ``dst``.
+
+		``self`` may be a file or a directory.
+
+		See :func:`shutil.move` for more details.
+
+		.. versionadded:: 3.2.0
+
+		:param dst:
+
+		:returns: The new location of ``self``.
+		:rtype: :class:`~.PathPlus`
+		"""
+
+		new_path = shutil.move(os.fspath(self), dst)
+		return self.__class__(new_path)
+
+	def stream(self, chunk_size: int = 1024) -> Iterator[bytes]:
+		"""
+		Stream the file in ``chunk_size`` sized chunks.
+
+		:param chunk_size: The chunk size, in bytes
+
+		.. versionadded:: 3.2.0
+		"""
+
+		with self.open("rb") as fp:
+			while True:
+				chunk = fp.read(chunk_size)
+				if not chunk:
+					break
+				yield chunk
+
 
 class PosixPathPlus(PathPlus, pathlib.PurePosixPath):
 	"""
@@ -1080,7 +1119,7 @@ class TemporaryPathPlus(tempfile.TemporaryDirectory):
 	.. autosummary-widths:: 6/16
 	"""
 
-	name: PathPlus  # type: ignore
+	name: PathPlus
 	"""
 	The temporary directory itself.
 
